From 330427e534f2b0f81fa57e4e0f6549022bc6c210 Mon Sep 17 00:00:00 2001
From: Fabio Ritrovato <exsephiroth87@gmail.com>
Date: Wed, 3 Feb 2010 23:42:16 +0100
Subject: [PATCH] [GSoC] luasd: use a configuration chain to pass parameters to SD

---
 include/vlc_services_discovery.h                 |    2 ++
 modules/gui/qt4/components/playlist/selector.cpp |    2 +-
 src/playlist/services_discovery.c                |   11 +++++++----
 3 files changed, 10 insertions(+), 5 deletions(-)

diff --git a/include/vlc_services_discovery.h b/include/vlc_services_discovery.h
index 7094def..d10ead9 100644
--- a/include/vlc_services_discovery.h
+++ b/include/vlc_services_discovery.h
@@ -48,6 +48,8 @@ struct services_discovery_t
 
     vlc_event_manager_t event_manager;      /* Accessed through Setters for non class function */
 
+    config_chain_t *p_cfg;
+
     services_discovery_sys_t *p_sys;
 };
 
diff --git a/modules/gui/qt4/components/playlist/selector.cpp b/modules/gui/qt4/components/playlist/selector.cpp
index c4c5813..416fb2f 100644
--- a/modules/gui/qt4/components/playlist/selector.cpp
+++ b/modules/gui/qt4/components/playlist/selector.cpp
@@ -173,7 +173,7 @@ void PLSelector::setSource( QTreeWidgetItem *item )
 
     if( i_type == SD_TYPE )
     {
-        pl_item = playlist_ChildSearchName( THEPL->p_root, qtu( item->data(0, LONGNAME_ROLE ).toString() ) );
+        pl_item = playlist_ChildSearchName( THEPL->p_root, qtu( item->data(0, NAME_ROLE ).toString() ) );
         if( item->data( 0, SPECIAL_ROLE ).toInt() == IS_PODCAST )
         {
             if( pl_item && !sd_loaded )
diff --git a/src/playlist/services_discovery.c b/src/playlist/services_discovery.c
index a0e5a74..e565e80 100644
--- a/src/playlist/services_discovery.c
+++ b/src/playlist/services_discovery.c
@@ -280,10 +280,13 @@ int playlist_ServicesDiscoveryAdd( playlist_t *p_playlist, const char *psz_modul
     if( !p_sd )
         return VLC_ENOMEM;
 
-    module_t *m = module_find_by_shortcut( psz_module );
+    char *psz_name = NULL;
+    config_ChainCreate( &psz_name, &p_sd->p_cfg, psz_module );
+
+    module_t *m = module_find_by_shortcut( psz_name );
     if( !m )
     {
-        msg_Err( p_playlist, "No such module: %s", psz_module );
+        msg_Err( p_playlist, "No such module: %s", psz_name );
         vlc_sd_Destroy( p_sd );
         return VLC_EGENERIC;
     }
@@ -300,7 +303,7 @@ int playlist_ServicesDiscoveryAdd( playlist_t *p_playlist, const char *psz_modul
     playlist_item_t *p_node;
 
     PL_LOCK;
-    p_node = playlist_NodeCreate( p_playlist, module_get_name( m, true ),
+    p_node = playlist_NodeCreate( p_playlist, psz_module,
                                   p_playlist->p_root, 0, NULL );
     PL_UNLOCK;
     module_release( m );
@@ -313,7 +316,7 @@ int playlist_ServicesDiscoveryAdd( playlist_t *p_playlist, const char *psz_modul
                       vlc_ServicesDiscoveryItemRemoved,
                       playlist_sd_item_removed, p_node );
 
-    if( !vlc_sd_Start( p_sd, psz_module ) )
+    if( !vlc_sd_Start( p_sd, psz_name ) )
     {
         vlc_sd_Destroy( p_sd );
         free( p_sds );
-- 
1.6.0.4

